==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/List/Partition.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v193	((void*)startLabel+60)
#define FN_List_46Prelude_46147_46select	((void*)startLabel+92)
#define v194	((void*)startLabel+135)
#define v196	((void*)startLabel+153)
#define CT_v199	((void*)startLabel+184)
#define F0_List_46Prelude_46147_46select	((void*)startLabel+192)
#define FN_LAMBDA190	((void*)startLabel+228)
#define CT_v201	((void*)startLabel+260)
#define CF_LAMBDA190	((void*)startLabel+268)
#define FN_LAMBDA189	((void*)startLabel+280)
#define CT_v203	((void*)startLabel+304)
#define F0_LAMBDA189	((void*)startLabel+312)
#define FN_LAMBDA188	((void*)startLabel+324)
#define CT_v205	((void*)startLabel+348)
#define F0_LAMBDA188	((void*)startLabel+356)
#define FN_LAMBDA187	((void*)startLabel+368)
#define CT_v210	((void*)startLabel+404)
#define F0_LAMBDA187	((void*)startLabel+412)
#define ST_v192	((void*)startLabel+416)
#define ST_v198	((void*)startLabel+431)
#define ST_v208	((void*)startLabel+458)
#define ST_v202	((void*)startLabel+479)
#define ST_v204	((void*)startLabel+506)
#define ST_v200	((void*)startLabel+533)
extern Node TM_List[];
extern Node FN_Prelude_46foldr[];
extern Node TMSUB_List[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v193)
,};
Node FN_List_46partition[] = {
  useLabel(TM_List)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_IN3,HEAP_CVAL_IN3,HEAP_CVAL_N1,4)
, bytes2word(HEAP_OFF_N1,3,HEAP_OFF_N1,3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,8)
, bytes2word(HEAP_OFF_N1,5,HEAP_ARG,2)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTR(0,2,0)
, CONSTR(0,0,0)
, 100001
, useLabel(ST_v192)
,	/* CT_v193: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_List_46partition[] = {
  CAPTAG(useLabel(FN_List_46partition),2)
, CAPTAG(useLabel(FN_List_46Prelude_46147_46select),2)
, VAPTAG(useLabel(FN_Prelude_46foldr))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v199)
,	/* FN_List_46Prelude_46147_46select: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(3,PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(3,PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1)
, bytes2word(5,PUSH_ARG_I2,PUSH_ZAP_ARG_I1,ZAP_ARG_I3)
, bytes2word(ZAP_STACK_P1,4,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,14,0,HEAP_CVAL_IN3)
, bytes2word(HEAP_ARG,2,HEAP_P1,0)
, bytes2word(PUSH_HEAP,HEAP_CVAL_N1,4,HEAP_OFF_N1)
,	/* v194: (byte 3) */
  bytes2word(4,HEAP_I2,RETURN,PUSH_CVAL_P1)
, bytes2word(6,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(13,0,HEAP_CVAL_IN3,HEAP_ARG)
, bytes2word(2,HEAP_I1,PUSH_HEAP,HEAP_CVAL_N1)
, bytes2word(4,HEAP_I1,HEAP_OFF_N1,5)
,	/* v196: (byte 1) */
  bytes2word(RETURN,HEAP_CVAL_P1,7,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,8,HEAP_OFF_N1,2)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTR(0,2,0)
, CONSTR(1,2,0)
, 110034
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(6,3)
, 0
,	/* F0_List_46Prelude_46147_46select: (byte 0) */
  CAPTAG(useLabel(FN_List_46Prelude_46147_46select),3)
, VAPTAG(useLabel(FN_LAMBDA187))
, VAPTAG(useLabel(FN_LAMBDA188))
, VAPTAG(useLabel(FN_LAMBDA189))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA190))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v201)
,	/* FN_LAMBDA190: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v200)
, 110034
, useLabel(ST_v198)
,	/* CT_v201: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA190: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA190))
, bytes2word(1,0,0,1)
, useLabel(CT_v203)
,	/* FN_LAMBDA189: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110045
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA189: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA189),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v205)
,	/* FN_LAMBDA188: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110048
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA188: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA188),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v210)
,	/* FN_LAMBDA187: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,PUSH_HEAP,HEAP_CVAL_IN3)
, bytes2word(HEAP_I2,HEAP_I1,RETURN,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,2,0)
, 110043
, useLabel(ST_v208)
,	/* CT_v210: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA187: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA187),1)
,	/* ST_v192: (byte 0) */
  bytes2word(76,105,115,116)
, bytes2word(46,112,97,114)
, bytes2word(116,105,116,105)
,	/* ST_v198: (byte 3) */
  bytes2word(111,110,0,76)
, bytes2word(105,115,116,46)
, bytes2word(112,97,114,116)
, bytes2word(105,116,105,111)
, bytes2word(110,58,49,49)
, bytes2word(58,51,52,45)
, bytes2word(49,50,58,55)
,	/* ST_v208: (byte 2) */
  bytes2word(53,0,76,105)
, bytes2word(115,116,46,112)
, bytes2word(97,114,116,105)
, bytes2word(116,105,111,110)
, bytes2word(58,49,49,58)
,	/* ST_v202: (byte 3) */
  bytes2word(52,51,0,76)
, bytes2word(105,115,116,46)
, bytes2word(112,97,114,116)
, bytes2word(105,116,105,111)
, bytes2word(110,58,49,49)
, bytes2word(58,52,53,45)
, bytes2word(49,49,58,52)
,	/* ST_v204: (byte 2) */
  bytes2word(54,0,76,105)
, bytes2word(115,116,46,112)
, bytes2word(97,114,116,105)
, bytes2word(116,105,111,110)
, bytes2word(58,49,49,58)
, bytes2word(52,56,45,49)
, bytes2word(49,58,52,57)
,	/* ST_v200: (byte 1) */
  bytes2word(0,76,105,115)
, bytes2word(116,58,32,80)
, bytes2word(97,116,116,101)
, bytes2word(114,110,32,109)
, bytes2word(97,116,99,104)
, bytes2word(32,102,97,105)
, bytes2word(108,117,114,101)
, bytes2word(32,105,110,32)
, bytes2word(102,117,110,99)
, bytes2word(116,105,111,110)
, bytes2word(32,97,116,32)
, bytes2word(49,49,58,51)
, bytes2word(52,45,49,50)
, bytes2word(58,55,53,46)
, bytes2word(0,0,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/List/Partition.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v198	((void*)startLabel+60)
#define FN_List_46Prelude_46152_46select	((void*)startLabel+92)
#define v199	((void*)startLabel+135)
#define v201	((void*)startLabel+153)
#define CT_v204	((void*)startLabel+184)
#define F0_List_46Prelude_46152_46select	((void*)startLabel+192)
#define FN_LAMBDA195	((void*)startLabel+228)
#define CT_v206	((void*)startLabel+260)
#define CF_LAMBDA195	((void*)startLabel+268)
#define FN_LAMBDA194	((void*)startLabel+280)
#define CT_v208	((void*)startLabel+304)
#define F0_LAMBDA194	((void*)startLabel+312)
#define FN_LAMBDA193	((void*)startLabel+324)
#define CT_v210	((void*)startLabel+348)
#define F0_LAMBDA193	((void*)startLabel+356)
#define FN_LAMBDA192	((void*)startLabel+368)
#define CT_v215	((void*)startLabel+404)
#define F0_LAMBDA192	((void*)startLabel+412)
#define ST_v197	((void*)startLabel+416)
#define ST_v203	((void*)startLabel+431)
#define ST_v213	((void*)startLabel+458)
#define ST_v207	((void*)startLabel+479)
#define ST_v209	((void*)startLabel+506)
#define ST_v205	((void*)startLabel+533)
extern Node TM_List[];
extern Node FN_Prelude_46foldr[];
extern Node TMSUB_List[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v198)
,};
Node FN_List_46partition[] = {
  useLabel(TM_List)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_IN3,HEAP_CVAL_IN3,HEAP_CVAL_N1,4)
, bytes2word(HEAP_OFF_N1,3,HEAP_OFF_N1,3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,8)
, bytes2word(HEAP_OFF_N1,5,HEAP_ARG,2)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTR(0,2,0)
, CONSTR(0,0,0)
, 100001
, useLabel(ST_v197)
,	/* CT_v198: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_List_46partition[] = {
  CAPTAG(useLabel(FN_List_46partition),2)
, CAPTAG(useLabel(FN_List_46Prelude_46152_46select),2)
, VAPTAG(useLabel(FN_Prelude_46foldr))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v204)
,	/* FN_List_46Prelude_46152_46select: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(3,PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(3,PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1)
, bytes2word(5,PUSH_ARG_I2,PUSH_ZAP_ARG_I1,ZAP_ARG_I3)
, bytes2word(ZAP_STACK_P1,4,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,14,0,HEAP_CVAL_IN3)
, bytes2word(HEAP_ARG,2,HEAP_P1,0)
, bytes2word(PUSH_HEAP,HEAP_CVAL_N1,4,HEAP_OFF_N1)
,	/* v199: (byte 3) */
  bytes2word(4,HEAP_I2,RETURN,PUSH_CVAL_P1)
, bytes2word(6,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(13,0,HEAP_CVAL_IN3,HEAP_ARG)
, bytes2word(2,HEAP_I1,PUSH_HEAP,HEAP_CVAL_N1)
, bytes2word(4,HEAP_I1,HEAP_OFF_N1,5)
,	/* v201: (byte 1) */
  bytes2word(RETURN,HEAP_CVAL_P1,7,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,8,HEAP_OFF_N1,2)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTR(0,2,0)
, CONSTR(1,2,0)
, 110034
, useLabel(ST_v203)
,	/* CT_v204: (byte 0) */
  HW(6,3)
, 0
,	/* F0_List_46Prelude_46152_46select: (byte 0) */
  CAPTAG(useLabel(FN_List_46Prelude_46152_46select),3)
, VAPTAG(useLabel(FN_LAMBDA192))
, VAPTAG(useLabel(FN_LAMBDA193))
, VAPTAG(useLabel(FN_LAMBDA194))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA195))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v206)
,	/* FN_LAMBDA195: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v205)
, 110034
, useLabel(ST_v203)
,	/* CT_v206: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA195: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA195))
, bytes2word(1,0,0,1)
, useLabel(CT_v208)
,	/* FN_LAMBDA194: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110045
, useLabel(ST_v207)
,	/* CT_v208: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA194: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA194),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v210)
,	/* FN_LAMBDA193: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110048
, useLabel(ST_v209)
,	/* CT_v210: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA193: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA193),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v215)
,	/* FN_LAMBDA192: (byte 0) */
  useLabel(TMSUB_List)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,PUSH_HEAP,HEAP_CVAL_IN3)
, bytes2word(HEAP_I2,HEAP_I1,RETURN,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,2,0)
, 110043
, useLabel(ST_v213)
,	/* CT_v215: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA192: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA192),1)
,	/* ST_v197: (byte 0) */
  bytes2word(76,105,115,116)
, bytes2word(46,112,97,114)
, bytes2word(116,105,116,105)
,	/* ST_v203: (byte 3) */
  bytes2word(111,110,0,76)
, bytes2word(105,115,116,46)
, bytes2word(112,97,114,116)
, bytes2word(105,116,105,111)
, bytes2word(110,58,49,49)
, bytes2word(58,51,52,45)
, bytes2word(49,50,58,55)
,	/* ST_v213: (byte 2) */
  bytes2word(53,0,76,105)
, bytes2word(115,116,46,112)
, bytes2word(97,114,116,105)
, bytes2word(116,105,111,110)
, bytes2word(58,49,49,58)
,	/* ST_v207: (byte 3) */
  bytes2word(52,51,0,76)
, bytes2word(105,115,116,46)
, bytes2word(112,97,114,116)
, bytes2word(105,116,105,111)
, bytes2word(110,58,49,49)
, bytes2word(58,52,53,45)
, bytes2word(49,49,58,52)
,	/* ST_v209: (byte 2) */
  bytes2word(54,0,76,105)
, bytes2word(115,116,46,112)
, bytes2word(97,114,116,105)
, bytes2word(116,105,111,110)
, bytes2word(58,49,49,58)
, bytes2word(52,56,45,49)
, bytes2word(49,58,52,57)
,	/* ST_v205: (byte 1) */
  bytes2word(0,76,105,115)
, bytes2word(116,58,32,80)
, bytes2word(97,116,116,101)
, bytes2word(114,110,32,109)
, bytes2word(97,116,99,104)
, bytes2word(32,102,97,105)
, bytes2word(108,117,114,101)
, bytes2word(32,105,110,32)
, bytes2word(102,117,110,99)
, bytes2word(116,105,111,110)
, bytes2word(32,97,116,32)
, bytes2word(49,49,58,51)
, bytes2word(52,45,49,50)
, bytes2word(58,55,53,46)
, bytes2word(0,0,0,0)
,};
